# Containers

## Object Container
::: fdtdx.objects.container.ObjectContainer
Container for managing simulation objects and their relationships.

::: fdtdx.objects.container.ParameterContainer
Type alias for parameter dictionaries containing JAX arrays.

## Array Container
::: fdtdx.objects.container.ArrayContainer
Container for simulation field arrays and states.

::: fdtdx.objects.container.SimulationState
Type alias for time step and array state tuple.

## Array Management
::: fdtdx.objects.container.reset_array_container
Reset array container fields and states.
